package
Version:
v1.0.0
Opens a new window with list of versions in this module.
Published: Apr 12, 2022
License: MIT
Opens a new window with license information.
Imports: 6
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type IPStats struct {
TotalRequests int
}
type StatsResponse struct {
Message struct {
TotalRequests int `json:"total_requests"`
} `json:"message"`
Error bool `json:"error"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.